<?php

/**
 * Gateway_Management controller.
 *
 * @category   Apps
 * @package    Gateway_Management
 * @subpackage Views
 * @author     ADAMnetworks <support@adamnet.works>
 * @copyright  2015-2022 ADAMnetworks
 * @license    All rights reserved
 * @link       https://adamnet.works
 */

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

class Gateway_Management_Ajax extends ClearOS_Controller
{
    ///////////////////////////////////////////////////////////////////////////////
    // V A R I A B L E S
    ///////////////////////////////////////////////////////////////////////////////

    // Initialized by constructor
    protected $dir = '';

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Ajax controller constructor.
     */
    function __construct()
    {
        $this->dir = basename(dirname(__DIR__));

        // Load dependencies
        //------------------
        $this->load->library($this->dir . '/Dashboard');
        $this->load->library($this->dir . '/Service');
        $this->load->library($this->dir . '/Util');

        // Send headers
        //-------------
        header('Cache-Control: no-cache, must-revalidate');
        header('Expires: Mon, 1 Jan 2000 00:00:00 GMT');
        header('Content-type: application/json');
    }

    /**
     * Default controller.
     *
     * @return void
     */
    function index()
    {
        $this->_404('Page does not exist');
    }

    /**
     * Retrieve json from another location.
     *
     * @param string $what info to request
     * @param string $arg  parameters needed for the request
     *
     * @return void
     */
    function dashboard()
    {
        $response = $this->dashboard->register();

        header($response['header']);
        echo $response['body'];
    }

    /**
     * Retrieve subscription status.
     *
     * @return void
     */
    function subscription_status()
    {
        $this->dashboard->get_subscription_status();
    }

    /**
     * Suggest a blockpage IP.
     *
     * @return void
     */
    function suggest_ip()
    {
        $result = $this->service->suggest_http_address();
        if ($result)
            echo '{"ip":"' . $result . '","msg": "Suggested address.","status":"success"}';
        else
            echo '{"msg": "' . $this->util->lang('suggest_ip_failed') . '","status":"danger"}';
    }

    /**
     * Check blockpage IP address.
     *
     * @param string $ip IP for blockpage
     *
     * @return void
     */
    function validate_ip($ip, $netmask = '')
    {
        // Convert - back to a /

        $ip = str_replace('-', '/', $ip);
        $result = $this->service->validate_http_address($ip);
        if ($result)
            echo '{"ip":"' . $ip . '","msg": "' . $result . '","status":"danger"}';
        else
            echo '{"ip":"' . $ip . '","msg": "' . $this->util->lang('blockpage_ip_available') . '","status":"success"}';
    }

    /**
     * Returns a 404 response with message.
     *
     * @param string $message error message
     *
     * @return none
     */
    protected function _404($message = FALSE)
    {
        clearos_profile(__METHOD__, __LINE__);

        if (!$message) {
            $message = 'Page does not exist.';
        }

        header("HTTP/1.0 404 Not Found");
        echo '{"result":false,"message":"' . $message . '"}';
        exit;
    }
}
