<?php

/**
 * Gateway_Management settings controller.
 *
 * @category   Apps
 * @package    Gateway_Management
 * @subpackage Controllers
 * @author     ADAMnetworks <support@adamnet.works>
 * @copyright  2015-2022 ADAMnetworks
 * @license    All rights reserved
 * @link       https://adamnet.works
 */

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

class Gateway_Management_Settings extends ClearOS_Controller
{
    ///////////////////////////////////////////////////////////////////////////////
    // V A R I A B L E S
    ///////////////////////////////////////////////////////////////////////////////

    // Initialized by constructor
    protected $dir = '';
    protected $webdir = '';

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Settings constructor.
     *
     * @param string $basename app basename
     */

    function __construct($basename = NULL)
    {
        $this->dir = basename(dirname(__DIR__));
        $this->webdir = ($basename) ? $basename : $this->dir;
    }

    /**
     * General settings overview.
     *
     * @return view
     */

    function index()
    {
        $this->_view_edit('view');
    }

    /**
     * General settings edit view.
     *
     * @return view
     */

    function edit()
    {
        $this->_view_edit('edit');
    }

    /**
     * Common view/edit form
     *
     * @param string $form_type form type
     *
     * @return view
     */

    function _view_edit($form_type)
    {
        // Load libraries
        //---------------

        $this->load->library($this->dir . '/Service');
        $this->load->library($this->dir . '/Util');
        $this->load->library('network/Network');

        // Set validation rules
        //---------------------

        $this->form_validation->set_policy('enabled', $this->dir . '/Service', 'validate_enabled', FALSE);
        $this->form_validation->set_policy('http_address', $this->dir . '/Service', 'validate_http_address', TRUE);
        $this->form_validation->set_policy('block_private_subnets', $this->dir . '/Service', 'validate_block_private_subnets', FALSE);

        $form_ok = $this->form_validation->run();

        // Handle form submit
        //-------------------
        if (($this->input->post('submit') && $form_ok)) {
            try {
                $http_address = $this->input->post('http_address');
                $http_address_result = $this->service->set_http_address($http_address);

                $enabled = (bool) $this->input->post('enabled');
                $enabled_result = $this->service->set_enabled($enabled);

                $block_private_subnets = (bool) $this->input->post('block_private_subnets');
                $bps_result = $this->service->set_block_private_subnets($block_private_subnets);

                $this->service->update_config();
                $this->service->update_firewall();

                // If the config changes or this gets enabled, restart the daemons
                if (($enabled && $http_address_result) || !$enabled_result) {
                    $this->service->restart_daemons();
                }

                redirect('/' . $this->webdir);
                return;
            } catch (Engine_Exception $e) {
                $this->page->view_exception($e->get_message());
                return;
            }
        }

        // Load view data
        //---------------

        try {
            // setup variables for view page
            $data['basename'] = $this->webdir;
            $data['form_type'] = $form_type;
            $data['box_id'] = $this->service->get_box_id();
            $data['enabled'] = $this->service->is_enabled();
            $data['block_private_subnets'] = $this->service->get_block_private_subnets();
            $data['http_address'] = $this->service->get_http_address();
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }

        // Load views
        //-----------

        $this->page->view_form($this->dir . '/settings', $data, lang('base_settings'), $options);
    }
}
