<?php

/**
 * Gateway Management javascript helper.
 *
 * @category   apps
 * @package    gateway-management-business
 * @subpackage javascript
 * @author     ADAMnetworks <support@adamnet.works>
 * @copyright  2015-2022 ADAMnetworks
 * @license    All rights reserved
 * @link       https://adamnet.works
 */

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

// Classes
//--------

use \clearos\apps\gateway_management\Util as Util;

clearos_load_library('gateway_management/Util');

$util = new Util();

///////////////////////////////////////////////////////////////////////////////
// J A V A S C R I P T
///////////////////////////////////////////////////////////////////////////////

header('Content-Type:application/x-javascript');
?>
(function() {
'use strict';

var ajax_path = '/app/<?php echo $util->get_dir(); ?>/ajax';

/* All below is brand-friendly */
var address_request;
var content_class;
var last_address;

$(document).ready(function() {
setup_variables_by_version();

// shouldn't be triggered on set up page, and must be enabled
var el = $('#dt_dashboard_msg.enabled');
if (el.length) {
check_dashboard_status();
}

// check http address
var http_address_el = $('#http_address');

http_address_el.on('change keyup paste', function() {
validate_http_address(http_address_el);
});

if (!http_address_el.val()) {
suggest_http_address(http_address_el);
}

var enabled_el = $('#enabled');
var settings_el = $('#dt_settings');

toggle_settings(enabled_el, settings_el);

enabled_el.change(function() {
toggle_settings(enabled_el, settings_el);
});
});

function toggle_settings(enabled_el, settings_el) {
if (enabled_el.prop('checked')) {
settings_el.show();
} else {
settings_el.hide();
}
};

function setup_variables_by_version() {
if ($('#dt_content .theme-infobox-text').length) {
// ClearOS 6
content_class = '.theme-infobox-text';

} else if ($('#dt_content .theme-infobox-content').length) {
// ClearOS 7
content_class = '.theme-infobox-content';

} else {
// Unknown. Style won't be right, but at least messages will display
content_class = '';
}
}

function status_to_color(status) {
var el = $('<p></p>').appendTo('body');
var color = el.addClass('text-' + status).css('color');
el.remove();
return color;
}

function check_dashboard_status() {
$.ajax({
url: ajax_path + '/dashboard',
type: 'GET',
success: function (data) {
set_dashboard_msg(data.message, 'success');
},
error: function (error) {
if (error.responseJSON && error.responseJSON.message) {
set_dashboard_msg(error.responseJSON.message, 'danger');
} else if (error.responseJSON && error.responseJSON.errors) {
set_dashboard_msg('Error registering your account.', 'danger');
} else {
set_dashboard_msg('Error checking account status.', 'danger');
}
}
});
}

function set_dashboard_msg(msg, status) {
var el = $('#dt_dashboard_msg');

var color = status_to_color(status);
el.html(msg).css('color', color);
}

function validate_http_address(el) {
var value = el.val();

// if address has not changed, don't recheck it
if (last_address === value) {
return;
}

if (address_request) {
address_request.abort();
}

// don't interpret / as a path separator
value = value.replace('/', '-');

if (!value) {
suggest_http_address(el);
return;
}

set_http_address_msg('Checking address...', 'muted', true);
last_address = value;

address_request = $.ajax({
url: ajax_path + '/validate_ip/' + value,
type: 'GET',
success: function (data) {
// display message
set_http_address_msg(data.msg, data.status);
},
error: function (xhr) {
if (!xhr.getAllResponseHeaders()) {
// page navigation, ignore
return;
}
set_http_address_msg('Unable to check address.', 'danger');
}
});
}

function suggest_http_address(el) {
if (last_address === '') {
// If already suggesting, allow that request to complete
return;
}

if (address_request) {
address_request.abort();
}

last_address = '';

set_http_address_msg('Searching for address...', 'muted', true);
address_request = $.ajax({
url: ajax_path + '/suggest_ip',
type: 'GET',
success: function (data) {
el.val(data.ip);
last_address = data.ip;

set_http_address_msg(data.msg, data.status);
},
error: function (xhr) {
if (!xhr.getAllResponseHeaders()) {
// page navigation, ignore
return;
}
set_http_address_msg('Unable to suggest address.', 'danger');
}
});
}

function set_http_address_msg(msg, status, loading) {
var error_id = 'http_address_error';
var msg_box = $('#' + error_id);
if (!msg_box.length) {
$('#http_address').after('<div class="theme-validation-error" id="' + error_id + '"></div>');
msg_box = $('#' + error_id);
}

if (loading) {
msg = '<i class="fa fa-spin fa-spinner"></i> ' + msg;
}

var color = status_to_color(status);
msg_box.html(msg).css('color', color);
}
}());
