<?php

/**
 * adam:ONE controller.
 *
 * @category   Apps
 * @package    Gateway_Management
 * @subpackage Controllers
 * @author     ADAMnetworks <support@adamnet.works>
 * @copyright  2015-2022 ADAMnetworks
 * @license    All rights reserved
 * @link       https://adamnet.works
 */

///////////////////////////////////////////////////////////////////////////////
// Form handler
///////////////////////////////////////////////////////////////////////////////

$buttons = array();
if ($form_type === 'edit') {
    $read_only = FALSE;
    $buttons[] = form_submit_update('submit');
    if ($enabled) {
        $buttons[] = anchor_cancel('/app/' . $basename);
    }
} else {
    $read_only = TRUE;
    $buttons[] = anchor_edit('/app/' . $basename . '/settings/edit');
}

///////////////////////////////////////////////////////////////////////////////
// Form
///////////////////////////////////////////////////////////////////////////////

// Configure
$this->service->verify_setup();
if ($enabled) {
    // Tell the user about any issues
    $issues = $this->service->get_issues();
    if ($issues) {
        echo infobox_warning('Warning', implode("<br>\n", $issues));
    }
}

// Display warnings
$warnings = $this->service->get_warnings();

if (!$enabled) {
    // Disabled warning should be the first warning
    array_unshift($warnings, array(
        'title' => $this->util->lang('disabled_title'),
        'message' => $this->util->lang('disabled_text'),
    ));
}

foreach ($warnings as $warning) {
    echo infobox_warning($warning['title'], $warning['message']);
}

// Begin form
echo form_open($basename . '/settings/edit');
echo form_header($this->util->lang('info'));

// box id
if ($box_id) {
    echo field_view($this->util->lang('box_id'), $box_id, NULL, NULL, array('id' => 'adam_boxid'));
}

// Enable
echo field_checkbox('enabled', $enabled, $this->util->lang('enabled'), $read_only);

// Configuration
if (!$read_only) {
    echo '<div id="dt_settings">';
}

// Block page IP
echo field_input('http_address', $http_address, $this->util->lang('blockpage_ip'), $read_only);

// Block private subnets
echo field_checkbox('block_private_subnets', $block_private_subnets, $this->util->lang('block_private_subnets'), $read_only);

if (!$read_only) {
    echo "</div>\n";
}

// buttons
echo field_button_set($buttons);

echo form_footer();
echo form_close();
